@@ -47,9 +47,11 @@ import org.opennms.netmgt.model.events.EventBuilder;
 import org.opennms.netmgt.telemetry.api.receiver.Parser;
 import org.opennms.netmgt.telemetry.api.receiver.TelemetryMessage;
 import org.opennms.netmgt.telemetry.protocols.netflow.parser.ie.RecordProvider;
+import org.opennms.netmgt.telemetry.protocols.netflow.parser.ie.Value;
 import org.opennms.netmgt.telemetry.protocols.netflow.parser.session.SequenceNumberTracker;
 import org.opennms.netmgt.telemetry.protocols.netflow.parser.session.Session;
 import org.opennms.netmgt.telemetry.protocols.netflow.parser.transport.MessageBuilder;
+import org.opennms.netmgt.telemetry.protocols.netflow.parser.transport.TransportValueVisitor;
 import org.opennms.netmgt.telemetry.protocols.netflow.transport.FlowMessage;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -132,6 +134,8 @@ public abstract class ParserBase implements Parser {
 
     private ExecutorService executor;
 
+    private boolean includeRawMessage = false;
+
     public ParserBase(final Protocol protocol,
                       final String name,
                       final AsyncDispatcher<TelemetryMessage> dispatcher,
@@ -298,6 +302,14 @@ public abstract class ParserBase implements Parser {
                             throw new RuntimeException(e);
                         }
 
+                        if (includeRawMessage) {
+                            for (final Value<?> value : record) {
+                                final TransportValueVisitor transportValueVisitor = new TransportValueVisitor();
+                                value.visit(transportValueVisitor);
+                                flowMessage.addRawMessage(transportValueVisitor.build());
+                            }
+                        }
+
                         // Check if the flow is valid (and maybe correct it)
                         final List<String> corrections = this.correctFlow(flowMessage);
                         if (!corrections.isEmpty()) {
@@ -398,4 +410,12 @@ public abstract class ParserBase implements Parser {
     protected SequenceNumberTracker sequenceNumberTracker() {
         return new SequenceNumberTracker(this.sequenceNumberPatience);
     }
+
+    public boolean isIncludeRawMessage() {
+        return includeRawMessage;
+    }
+
+    public void setIncludeRawMessage(boolean includeRawMessage) {
+        this.includeRawMessage = includeRawMessage;
+    }
 }
